Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(543)

Unified Diff: services/ui/ws/user_display_manager.h

Issue 2692863009: Remove usage of ws::Display in ws::UserDisplayManager. (Closed)
Patch Set: Fix mash_browser_tests. Created 3 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « services/ui/ws/test_utils.cc ('k') | services/ui/ws/user_display_manager.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: services/ui/ws/user_display_manager.h
diff --git a/services/ui/ws/user_display_manager.h b/services/ui/ws/user_display_manager.h
index 00d2732539a5ab152d58b7b524854720a9329149..16617d7597e3e727b4f7029bc455679ad34521c2 100644
--- a/services/ui/ws/user_display_manager.h
+++ b/services/ui/ws/user_display_manager.h
@@ -5,7 +5,6 @@
#ifndef SERVICES_UI_WS_USER_DISPLAY_MANAGER_H_
#define SERVICES_UI_WS_USER_DISPLAY_MANAGER_H_
-#include <set>
#include <vector>
#include "base/macros.h"
@@ -14,18 +13,19 @@
#include "services/ui/public/interfaces/display_manager.mojom.h"
#include "services/ui/ws/user_id.h"
+namespace display {
+class Display;
+}
+
namespace ui {
namespace ws {
-class Display;
-class DisplayManager;
class UserDisplayManagerDelegate;
// Provides per user display state.
class UserDisplayManager : public mojom::DisplayManager {
public:
- UserDisplayManager(ws::DisplayManager* display_manager,
- UserDisplayManagerDelegate* delegate,
+ UserDisplayManager(UserDisplayManagerDelegate* delegate,
const UserId& user_id);
~UserDisplayManager() override;
@@ -36,10 +36,10 @@ class UserDisplayManager : public mojom::DisplayManager {
mojo::InterfaceRequest<mojom::DisplayManager> request);
// Called when something about the display (e.g. pixel-ratio, size) changes.
- void OnDisplayUpdate(Display* display);
+ void OnDisplayUpdate(const display::Display& display);
- // Called by Display prior to |display| being removed and destroyed.
- void OnWillDestroyDisplay(Display* display);
+ // Called when |display_id| is being removed.
+ void OnWillDestroyDisplay(int64_t display_id);
// Called when the primary display changes.
void OnPrimaryDisplayChanged(int64_t primary_display_id);
@@ -53,15 +53,13 @@ class UserDisplayManager : public mojom::DisplayManager {
void OnObserverAdded(mojom::DisplayManagerObserver* observer);
// Fills in a WsDisplayPtr for |display|.
- mojom::WsDisplayPtr GetWsDisplayPtr(const Display& display);
+ mojom::WsDisplayPtr ToWsDisplayPtr(const display::Display& display);
std::vector<mojom::WsDisplayPtr> GetAllDisplays();
// Calls OnDisplays() on |observer|.
void CallOnDisplays(mojom::DisplayManagerObserver* observer);
- ws::DisplayManager* display_manager_;
-
UserDisplayManagerDelegate* delegate_;
const UserId user_id_;
« no previous file with comments | « services/ui/ws/test_utils.cc ('k') | services/ui/ws/user_display_manager.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698